#ifndef SPLINESDELTAFUNCTION_H
#define SPLINESDELTAFUNCTION_H

// ----------------------------------------------------------------------
//
// DeltaFucntion.h
//
// Struct embodying the Delta function concept IN THE CONTEXT OF Splines 
//
// DeltaFunction<d> has only one purpose -- to feed to a ctor of Spline<d>
// 
// Currently, we only have d=1.
//
// If a spline<1> D represents a delta function of strength s at location x,
// then the intent is for the following properties of integrate and 
// convolve to hold:
//
// D.integrate(a,b) = s if a <= x <= b, zero otherwise
//
// With f another spline, f.convolve(D) s*f(x) 
//
// ----------------------------------------------------------------------


namespace splines {

// The following template will be defined in this header:

template <unsigned int d> struct DeltaFunction;

// The following specializations will be defined in this header:

template <> struct DeltaFunction<1>;


// =================
// DeltaFunction <1> 
// =================

template <>
struct DeltaFunction<1> {

public:
 
  // Constructors and assignment

  // From an location, strength, and "effective infinity" height
  explicit DeltaFunction ( double location, 
                           double strength=1.0, 
                           double height=1000000.0 )
  : x(location)
  , integral(strength)
  , h(height)
  {}

  DeltaFunction() 
  : x(0.0)
  , integral(1.0)
  , h(1000000)
  { }

public:
  double x;
  double integral;
  double h;

};  

} // end of namespace splines


#endif  /* SPLINESDELTAFUNCTION_H */
